@@ -17,7 +17,7 @@ from maleo_metadata.schemas.parameter.client.blood_type import (
 
 
 class MaleoMetadataBloodTypeHTTPController(MaleoClientHTTPController):
-    async def get_blood_types(
+    async def read_blood_types(
         self,
         authentication: Authentication,
         parameters: ReadMultipleParameter,
@@ -67,7 +67,7 @@ class MaleoMetadataBloodTypeHTTPController(MaleoClientHTTPController):
             # Send request and wait for response
             return await client.get(url=url, params=params, headers=headers, auth=auth)
 
-    async def get_blood_type(
+    async def read_blood_type(
         self,
         authentication: Authentication,
         parameters: ReadSingleParameter,
