@@ -17,7 +17,7 @@ from maleo_metadata.schemas.parameter.client.gender import (
 
 
 class MaleoMetadataGenderHTTPController(MaleoClientHTTPController):
-    async def get_genders(
+    async def read_genders(
         self,
         authentication: Authentication,
         parameters: ReadMultipleParameter,
@@ -67,7 +67,7 @@ class MaleoMetadataGenderHTTPController(MaleoClientHTTPController):
             # Send request and wait for response
             return await client.get(url=url, params=params, headers=headers, auth=auth)
 
-    async def get_gender(
+    async def read_gender(
         self,
         authentication: Authentication,
         parameters: ReadSingleParameter,
