@@ -20,7 +20,7 @@ from maleo_metadata.schemas.parameter.client.medical_role import (
 
 
 class MaleoMetadataMedicalRoleHTTPController(MaleoClientHTTPController):
-    async def get_medical_roles(
+    async def read_medical_roles(
         self,
         authentication: Authentication,
         parameters: ReadMultipleParameter,
@@ -70,7 +70,7 @@ class MaleoMetadataMedicalRoleHTTPController(MaleoClientHTTPController):
             # Send request and wait for response
             return await client.get(url=url, params=params, headers=headers, auth=auth)
 
-    async def get_medical_roles_specializations(
+    async def read_medical_roles_specializations(
         self,
         authentication: Authentication,
         parameters: ReadMultipleRootSpecializationsParameter,
@@ -123,7 +123,7 @@ class MaleoMetadataMedicalRoleHTTPController(MaleoClientHTTPController):
             )
             return Response(response=response)  #  type: ignore
 
-    async def get_medical_role(
+    async def read_medical_role(
         self,
         authentication: Authentication,
         parameters: ReadSingleParameter,
@@ -173,7 +173,7 @@ class MaleoMetadataMedicalRoleHTTPController(MaleoClientHTTPController):
             # Send request and wait for response
             return await client.get(url=url, params=params, headers=headers, auth=auth)
 
-    async def get_medical_role_specializations(
+    async def read_medical_role_specializations(
         self,
         authentication: Authentication,
         parameters: ReadMultipleSpecializationsParameter,
