@@ -17,7 +17,7 @@ from maleo_metadata.schemas.parameter.client.organization_type import (
 
 
 class MaleoMetadataOrganizationTypeHTTPController(MaleoClientHTTPController):
-    async def get_organization_types(
+    async def read_organization_types(
         self,
         authentication: Authentication,
         parameters: ReadMultipleParameter,
@@ -67,7 +67,7 @@ class MaleoMetadataOrganizationTypeHTTPController(MaleoClientHTTPController):
             # Send request and wait for response
             return await client.get(url=url, params=params, headers=headers, auth=auth)
 
-    async def get_organization_type(
+    async def read_organization_type(
         self,
         authentication: Authentication,
         parameters: ReadSingleParameter,
