@@ -17,7 +17,7 @@ from maleo_metadata.schemas.parameter.client.service import (
 
 
 class MaleoMetadataServiceHTTPController(MaleoClientHTTPController):
-    async def get_services(
+    async def read_services(
         self,
         authentication: Authentication,
         parameters: ReadMultipleParameter,
@@ -67,7 +67,7 @@ class MaleoMetadataServiceHTTPController(MaleoClientHTTPController):
             # Send request and wait for response
             return await client.get(url=url, params=params, headers=headers, auth=auth)
 
-    async def get_service(
+    async def read_service(
         self,
         authentication: Authentication,
         parameters: ReadSingleParameter,
