@@ -17,7 +17,7 @@ from maleo_metadata.schemas.parameter.client.system_role import (
 
 
 class MaleoMetadataSystemRoleHTTPController(MaleoClientHTTPController):
-    async def get_system_roles(
+    async def read_system_roles(
         self,
         authentication: Authentication,
         parameters: ReadMultipleParameter,
@@ -67,7 +67,7 @@ class MaleoMetadataSystemRoleHTTPController(MaleoClientHTTPController):
             # Send request and wait for response
             return await client.get(url=url, params=params, headers=headers, auth=auth)
 
-    async def get_system_role(
+    async def read_system_role(
         self,
         authentication: Authentication,
         parameters: ReadSingleParameter,
