@@ -17,7 +17,7 @@ from maleo_metadata.schemas.parameter.client.user_type import (
 
 
 class MaleoMetadataUserTypeHTTPController(MaleoClientHTTPController):
-    async def get_user_types(
+    async def read_user_types(
         self,
         authentication: Authentication,
         parameters: ReadMultipleParameter,
@@ -67,7 +67,7 @@ class MaleoMetadataUserTypeHTTPController(MaleoClientHTTPController):
             # Send request and wait for response
             return await client.get(url=url, params=params, headers=headers, auth=auth)
 
-    async def get_user_type(
+    async def read_user_type(
         self,
         authentication: Authentication,
         parameters: ReadSingleParameter,
