@@ -30,7 +30,6 @@ from maleo_soma.schemas.operation.resource.result import (
 )
 from maleo_soma.schemas.operation.timestamp import OperationTimestamp
 from maleo_soma.schemas.request import RequestContext
-from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_soma.schemas.response import (
     SingleDataResponseSchema,
     MultipleDataResponseSchema,
@@ -41,16 +40,14 @@ from maleo_soma.utils.cache import build_key
 from maleo_soma.utils.logging import ClientLogger
 from maleo_metadata.client.controllers import MaleoMetadataGenderControllers
 from maleo_metadata.enums.general import ClientControllerType
+from maleo_metadata.constants.gender import RESOURCE
 from maleo_metadata.schemas.data.gender import GenderDataSchema
 from maleo_metadata.schemas.parameter.client.gender import ReadMultipleParameter
 from maleo_metadata.schemas.parameter.general.gender import ReadSingleParameter
 
 
 class MaleoMetadataGenderClientService(MaleoClientService):
-    RESOURCE = Resource(
-        identifier=ResourceIdentifier(key="genders", name="Gender", url_slug="genders"),
-        details=None,
-    )
+    RESOURCE = RESOURCE
 
     def __init__(
         self,
@@ -84,7 +81,7 @@ class MaleoMetadataGenderClientService(MaleoClientService):
             ),
         )
 
-    async def get_genders(
+    async def read_genders(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -163,7 +160,7 @@ class MaleoMetadataGenderClientService(MaleoClientService):
 
         # Retrieve genders using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_genders(
+            response = await self._controllers.http.read_genders(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
@@ -232,7 +229,7 @@ class MaleoMetadataGenderClientService(MaleoClientService):
             error.operation_schema.log(self._logger, LogLevel.CRITICAL)
             raise error
 
-    async def get_gender(
+    async def read_gender(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -312,7 +309,7 @@ class MaleoMetadataGenderClientService(MaleoClientService):
 
         # Retrieve genders using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_gender(
+            response = await self._controllers.http.read_gender(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
