@@ -30,7 +30,6 @@ from maleo_soma.schemas.operation.resource.result import (
 )
 from maleo_soma.schemas.operation.timestamp import OperationTimestamp
 from maleo_soma.schemas.request import RequestContext
-from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_soma.schemas.response import (
     SingleDataResponseSchema,
     MultipleDataResponseSchema,
@@ -41,18 +40,14 @@ from maleo_soma.utils.cache import build_key
 from maleo_soma.utils.logging import ClientLogger
 from maleo_metadata.client.controllers import MaleoMetadataMedicalRoleControllers
 from maleo_metadata.enums.general import ClientControllerType
+from maleo_metadata.constants.medical_role import RESOURCE
 from maleo_metadata.schemas.data.medical_role import MedicalRoleDataSchema
 from maleo_metadata.schemas.parameter.client.medical_role import ReadMultipleParameter
 from maleo_metadata.schemas.parameter.general.medical_role import ReadSingleParameter
 
 
 class MaleoMetadataMedicalRoleClientService(MaleoClientService):
-    RESOURCE = Resource(
-        identifier=ResourceIdentifier(
-            key="medical_roles", name="MedicalRole", url_slug="medical-roles"
-        ),
-        details=None,
-    )
+    RESOURCE = RESOURCE
 
     def __init__(
         self,
@@ -89,7 +84,7 @@ class MaleoMetadataMedicalRoleClientService(MaleoClientService):
             ),
         )
 
-    async def get_medical_roles(
+    async def read_medical_roles(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -168,7 +163,7 @@ class MaleoMetadataMedicalRoleClientService(MaleoClientService):
 
         # Retrieve medical roles using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_medical_roles(
+            response = await self._controllers.http.read_medical_roles(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
@@ -239,7 +234,7 @@ class MaleoMetadataMedicalRoleClientService(MaleoClientService):
             error.operation_schema.log(self._logger, LogLevel.CRITICAL)
             raise error
 
-    async def get_medical_role_specializations(
+    async def read_medical_role_specializations(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -318,7 +313,7 @@ class MaleoMetadataMedicalRoleClientService(MaleoClientService):
 
         # Retrieve medical roles using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_medical_roles(
+            response = await self._controllers.http.read_medical_roles(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
@@ -389,7 +384,7 @@ class MaleoMetadataMedicalRoleClientService(MaleoClientService):
             error.operation_schema.log(self._logger, LogLevel.CRITICAL)
             raise error
 
-    async def get_medical_role(
+    async def read_medical_role(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -469,7 +464,7 @@ class MaleoMetadataMedicalRoleClientService(MaleoClientService):
 
         # Retrieve medical roles using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_medical_role(
+            response = await self._controllers.http.read_medical_role(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
