@@ -30,7 +30,6 @@ from maleo_soma.schemas.operation.resource.result import (
 )
 from maleo_soma.schemas.operation.timestamp import OperationTimestamp
 from maleo_soma.schemas.request import RequestContext
-from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_soma.schemas.response import (
     SingleDataResponseSchema,
     MultipleDataResponseSchema,
@@ -41,6 +40,7 @@ from maleo_soma.utils.cache import build_key
 from maleo_soma.utils.logging import ClientLogger
 from maleo_metadata.client.controllers import MaleoMetadataOrganizationTypeControllers
 from maleo_metadata.enums.general import ClientControllerType
+from maleo_metadata.constants.organization_type import RESOURCE
 from maleo_metadata.schemas.data.organization_type import OrganizationTypeDataSchema
 from maleo_metadata.schemas.parameter.client.organization_type import (
     ReadMultipleParameter,
@@ -51,14 +51,7 @@ from maleo_metadata.schemas.parameter.general.organization_type import (
 
 
 class MaleoMetadataOrganizationTypeClientService(MaleoClientService):
-    RESOURCE = Resource(
-        identifier=ResourceIdentifier(
-            key="organization_types",
-            name="OrganizationType",
-            url_slug="organization-types",
-        ),
-        details=None,
-    )
+    RESOURCE = RESOURCE
 
     def __init__(
         self,
@@ -95,7 +88,7 @@ class MaleoMetadataOrganizationTypeClientService(MaleoClientService):
             ),
         )
 
-    async def get_organization_types(
+    async def read_organization_types(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -174,7 +167,7 @@ class MaleoMetadataOrganizationTypeClientService(MaleoClientService):
 
         # Retrieve organization types using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_organization_types(
+            response = await self._controllers.http.read_organization_types(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
@@ -245,7 +238,7 @@ class MaleoMetadataOrganizationTypeClientService(MaleoClientService):
             error.operation_schema.log(self._logger, LogLevel.CRITICAL)
             raise error
 
-    async def get_organization_type(
+    async def read_organization_type(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -325,7 +318,7 @@ class MaleoMetadataOrganizationTypeClientService(MaleoClientService):
 
         # Retrieve organization types using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_organization_type(
+            response = await self._controllers.http.read_organization_type(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
