@@ -30,7 +30,6 @@ from maleo_soma.schemas.operation.resource.result import (
 )
 from maleo_soma.schemas.operation.timestamp import OperationTimestamp
 from maleo_soma.schemas.request import RequestContext
-from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_soma.schemas.response import (
     SingleDataResponseSchema,
     MultipleDataResponseSchema,
@@ -41,18 +40,14 @@ from maleo_soma.utils.cache import build_key
 from maleo_soma.utils.logging import ClientLogger
 from maleo_metadata.client.controllers import MaleoMetadataServiceControllers
 from maleo_metadata.enums.general import ClientControllerType
+from maleo_metadata.constants.service import RESOURCE
 from maleo_metadata.schemas.data.service import ServiceDataSchema
 from maleo_metadata.schemas.parameter.client.service import ReadMultipleParameter
 from maleo_metadata.schemas.parameter.general.service import ReadSingleParameter
 
 
 class MaleoMetadataServiceClientService(MaleoClientService):
-    RESOURCE = Resource(
-        identifier=ResourceIdentifier(
-            key="services", name="Service", url_slug="services"
-        ),
-        details=None,
-    )
+    RESOURCE = RESOURCE
 
     def __init__(
         self,
@@ -86,7 +81,7 @@ class MaleoMetadataServiceClientService(MaleoClientService):
             ),
         )
 
-    async def get_services(
+    async def read_services(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -165,7 +160,7 @@ class MaleoMetadataServiceClientService(MaleoClientService):
 
         # Retrieve services using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_services(
+            response = await self._controllers.http.read_services(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
@@ -234,7 +229,7 @@ class MaleoMetadataServiceClientService(MaleoClientService):
             error.operation_schema.log(self._logger, LogLevel.CRITICAL)
             raise error
 
-    async def get_service(
+    async def read_service(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -314,7 +309,7 @@ class MaleoMetadataServiceClientService(MaleoClientService):
 
         # Retrieve services using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_service(
+            response = await self._controllers.http.read_service(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
