@@ -30,7 +30,6 @@ from maleo_soma.schemas.operation.resource.result import (
 )
 from maleo_soma.schemas.operation.timestamp import OperationTimestamp
 from maleo_soma.schemas.request import RequestContext
-from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_soma.schemas.response import (
     SingleDataResponseSchema,
     MultipleDataResponseSchema,
@@ -41,18 +40,14 @@ from maleo_soma.utils.cache import build_key
 from maleo_soma.utils.logging import ClientLogger
 from maleo_metadata.client.controllers import MaleoMetadataSystemRoleControllers
 from maleo_metadata.enums.general import ClientControllerType
+from maleo_metadata.constants.system_role import RESOURCE
 from maleo_metadata.schemas.data.system_role import SystemRoleDataSchema
 from maleo_metadata.schemas.parameter.client.system_role import ReadMultipleParameter
 from maleo_metadata.schemas.parameter.general.system_role import ReadSingleParameter
 
 
 class MaleoMetadataSystemRoleClientService(MaleoClientService):
-    RESOURCE = Resource(
-        identifier=ResourceIdentifier(
-            key="system_roles", name="SystemRole", url_slug="system-roles"
-        ),
-        details=None,
-    )
+    RESOURCE = RESOURCE
 
     def __init__(
         self,
@@ -86,7 +81,7 @@ class MaleoMetadataSystemRoleClientService(MaleoClientService):
             ),
         )
 
-    async def get_system_roles(
+    async def read_system_roles(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -165,7 +160,7 @@ class MaleoMetadataSystemRoleClientService(MaleoClientService):
 
         # Retrieve system roles using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_system_roles(
+            response = await self._controllers.http.read_system_roles(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
@@ -236,7 +231,7 @@ class MaleoMetadataSystemRoleClientService(MaleoClientService):
             error.operation_schema.log(self._logger, LogLevel.CRITICAL)
             raise error
 
-    async def get_system_role(
+    async def read_system_role(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -316,7 +311,7 @@ class MaleoMetadataSystemRoleClientService(MaleoClientService):
 
         # Retrieve system roles using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_system_role(
+            response = await self._controllers.http.read_system_role(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
