@@ -30,7 +30,6 @@ from maleo_soma.schemas.operation.resource.result import (
 )
 from maleo_soma.schemas.operation.timestamp import OperationTimestamp
 from maleo_soma.schemas.request import RequestContext
-from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_soma.schemas.response import (
     SingleDataResponseSchema,
     MultipleDataResponseSchema,
@@ -41,18 +40,14 @@ from maleo_soma.utils.cache import build_key
 from maleo_soma.utils.logging import ClientLogger
 from maleo_metadata.client.controllers import MaleoMetadataUserTypeControllers
 from maleo_metadata.enums.general import ClientControllerType
+from maleo_metadata.constants.user_type import RESOURCE
 from maleo_metadata.schemas.data.user_type import UserTypeDataSchema
 from maleo_metadata.schemas.parameter.client.user_type import ReadMultipleParameter
 from maleo_metadata.schemas.parameter.general.user_type import ReadSingleParameter
 
 
 class MaleoMetadataUserTypeClientService(MaleoClientService):
-    RESOURCE = Resource(
-        identifier=ResourceIdentifier(
-            key="user_types", name="UserType", url_slug="user-types"
-        ),
-        details=None,
-    )
+    RESOURCE = RESOURCE
 
     def __init__(
         self,
@@ -86,7 +81,7 @@ class MaleoMetadataUserTypeClientService(MaleoClientService):
             ),
         )
 
-    async def get_user_types(
+    async def read_user_types(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -165,7 +160,7 @@ class MaleoMetadataUserTypeClientService(MaleoClientService):
 
         # Retrieve user types using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_user_types(
+            response = await self._controllers.http.read_user_types(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
@@ -234,7 +229,7 @@ class MaleoMetadataUserTypeClientService(MaleoClientService):
             error.operation_schema.log(self._logger, LogLevel.CRITICAL)
             raise error
 
-    async def get_user_type(
+    async def read_user_type(
         self,
         request_context: RequestContext,
         authentication: Authentication,
@@ -314,7 +309,7 @@ class MaleoMetadataUserTypeClientService(MaleoClientService):
 
         # Retrieve user types using chosen controller
         if controller_type is ClientControllerType.HTTP:
-            response = await self._controllers.http.get_user_type(
+            response = await self._controllers.http.read_user_type(
                 authentication=authentication,
                 parameters=parameters,
                 authorization=authorization,
