@@ -1,5 +1,6 @@
 from typing import Callable, Dict
 from uuid import UUID
+from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_metadata.enums.medical_role import IdentifierType
 from maleo_metadata.types.base.medical_role import IdentifierValueType
 
@@ -14,3 +15,11 @@ IDENTIFIER_TYPE_VALUE_TYPE_MAP: Dict[
     IdentifierType.KEY: str,
     IdentifierType.NAME: str,
 }
+
+
+RESOURCE = Resource(
+    identifier=ResourceIdentifier(
+        key="medical_roles", name="MedicalRoled", url_slug="medical-roles"
+    ),
+    details=None,
+)
