@@ -1,5 +1,6 @@
 from typing import Callable, Dict
 from uuid import UUID
+from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_metadata.enums.organization_type import IdentifierType
 from maleo_metadata.types.base.organization_type import IdentifierValueType
 
@@ -13,3 +14,13 @@ IDENTIFIER_TYPE_VALUE_TYPE_MAP: Dict[
     IdentifierType.KEY: str,
     IdentifierType.NAME: str,
 }
+
+
+RESOURCE = Resource(
+    identifier=ResourceIdentifier(
+        key="organization_types",
+        name="OrganizationTypes",
+        url_slug="organization-types",
+    ),
+    details=None,
+)
