@@ -1,5 +1,6 @@
 from typing import Callable, Dict
 from uuid import UUID
+from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_metadata.enums.service import IdentifierType
 from maleo_metadata.types.base.service import IdentifierValueType
 
@@ -12,3 +13,9 @@ IDENTIFIER_TYPE_VALUE_TYPE_MAP: Dict[
     IdentifierType.KEY: str,
     IdentifierType.NAME: str,
 }
+
+
+RESOURCE = Resource(
+    identifier=ResourceIdentifier(key="services", name="Services", url_slug="services"),
+    details=None,
+)
