@@ -1,5 +1,6 @@
 from typing import Callable, Dict
 from uuid import UUID
+from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_metadata.enums.system_role import IdentifierType
 from maleo_metadata.types.base.system_role import IdentifierValueType
 
@@ -13,3 +14,11 @@ IDENTIFIER_TYPE_VALUE_TYPE_MAP: Dict[
     IdentifierType.KEY: str,
     IdentifierType.NAME: str,
 }
+
+
+RESOURCE = Resource(
+    identifier=ResourceIdentifier(
+        key="system_roles", name="SystemRoles", url_slug="system-roles"
+    ),
+    details=None,
+)
