@@ -1,5 +1,6 @@
 from typing import Callable, Dict
 from uuid import UUID
+from maleo_soma.schemas.resource import Resource, ResourceIdentifier
 from maleo_metadata.enums.user_type import IdentifierType
 from maleo_metadata.types.base.user_type import IdentifierValueType
 
@@ -13,3 +14,11 @@ IDENTIFIER_TYPE_VALUE_TYPE_MAP: Dict[
     IdentifierType.KEY: str,
     IdentifierType.NAME: str,
 }
+
+
+RESOURCE = Resource(
+    identifier=ResourceIdentifier(
+        key="user_types", name="UserTypes", url_slug="user-types"
+    ),
+    details=None,
+)
